"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addAnalogProjectConfig = void 0;
const devkit_1 = require("@nx/devkit");
function addAnalogProjectConfig(tree, projectRoot, projectName, parsedTags, name, appsDir, nxPackageNamespace) {
    const isStandalone = appsDir === '.';
    const isNx = tree.exists('/nx.json');
    const workspaceAppsDir = isStandalone || !isNx ? '' : `${appsDir}/`;
    const targets = isNx ? 'targets' : 'architect';
    const builders = isNx ? 'executor' : 'builder';
    const projectConfiguration = {
        root: projectRoot,
        projectType: 'application',
        [targets]: {
            build: {
                [builders]: `@analogjs/platform:vite`,
                defaultConfiguration: 'production',
                configurations: {
                    development: {
                        mode: 'development',
                    },
                    production: {
                        sourcemap: false,
                        mode: 'production',
                    },
                },
            },
            serve: {
                [builders]: `@analogjs/platform:vite-dev-server`,
                defaultConfiguration: 'development',
                options: {
                    buildTarget: `${projectName}:build`,
                    port: 4200,
                },
                configurations: {
                    development: {
                        buildTarget: `${projectName}:build:development`,
                        hmr: true,
                    },
                    production: {
                        buildTarget: `${projectName}:build:production`,
                    },
                },
            },
            test: {
                [builders]: `@analogjs/platform:vitest`,
            },
        },
    };
    if (isNx) {
        projectConfiguration.targets['build'].outputs = [
            '{options.outputPath}',
            `{workspaceRoot}/dist/${workspaceAppsDir}${projectName}/.nitro`,
            `{workspaceRoot}/dist/${workspaceAppsDir}${projectName}/ssr`,
            `{workspaceRoot}/dist/${workspaceAppsDir}${projectName}/analog`,
        ];
        projectConfiguration[targets]['build'].options = {
            main: `${workspaceAppsDir}${projectName}/src/main.ts`,
            configFile: `${workspaceAppsDir}${projectName}/vite.config.ts`,
            outputPath: `dist/${workspaceAppsDir}${projectName}/client`,
            tsConfig: `${workspaceAppsDir}${projectName}/tsconfig.app.json`,
        };
        projectConfiguration[targets]['test'].outputs = [`{projectRoot}/coverage`];
        projectConfiguration.tags = parsedTags;
        projectConfiguration.sourceRoot = `${projectRoot}/src`;
    }
    else {
        projectConfiguration[targets]['build'].options = {
            main: `projects/${projectName}/src/main.ts`,
            configFile: `projects/${projectName}/vite.config.ts`,
            outputPath: `dist/projects/${projectName}/client`,
            tsConfig: `projects/${projectName}/tsconfig.app.json`,
        };
        projectConfiguration.sourceRoot = `src`;
    }
    if (isNx) {
        (0, devkit_1.addProjectConfiguration)(tree, name, projectConfiguration);
    }
    else {
        (0, devkit_1.updateJson)(tree, '/angular.json', (json) => {
            json.projects[projectName] = projectConfiguration;
            return json;
        });
    }
}
exports.addAnalogProjectConfig = addAnalogProjectConfig;
//# sourceMappingURL=add-analog-project-config.js.map