"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeAngularWorkspace = void 0;
const semver_1 = require("semver");
const devkit_1 = require("@nx/devkit");
const version_utils_1 = require("../../../utils/version-utils");
const minimum_supported_versions_1 = require("../versions/minimum-supported-versions");
const nx_dependencies_1 = require("../versions/nx-dependencies");
async function initializeAngularWorkspace(tree, installedNxVersion, normalizedOptions) {
    let angularVersion = (0, version_utils_1.getInstalledPackageVersion)(tree, '@angular/core');
    if (!angularVersion) {
        console.log('Angular has not been installed yet. Creating an Angular application');
        if ((0, semver_1.major)(installedNxVersion) >= 16) {
            angularVersion = await initWithNxNamespace(tree, installedNxVersion, normalizedOptions.skipFormat);
        }
        else {
            angularVersion = await initWithNrwlNamespace(tree, installedNxVersion, normalizedOptions.skipFormat);
        }
    }
    if ((0, minimum_supported_versions_1.belowMinimumSupportedAngularVersion)(angularVersion)) {
        throw new Error((0, devkit_1.stripIndents) `Analog only supports an Angular version of 15 and higher`);
    }
    return angularVersion;
}
exports.initializeAngularWorkspace = initializeAngularWorkspace;
const initWithNxNamespace = async (tree, installedNxVersion, skipFormat = true) => {
    const versions = (0, nx_dependencies_1.getNxDependencies)(installedNxVersion);
    (0, devkit_1.addDependenciesToPackageJson)(tree, {
        '@angular/animations': '^17.2.0',
        '@angular/common': '^17.2.0',
        '@angular/compiler': '^17.2.0',
        '@angular/core': '^17.2.0',
        '@angular/forms': '^17.2.0',
        '@angular/platform-browser': '^17.2.0',
        '@angular/platform-browser-dynamic': '^17.2.0',
        '@angular/platform-server': '^17.2.0',
        '@angular/router': '^17.2.0',
        rxjs: '~7.5.6',
        tslib: '^2.4.0',
        'zone.js': '~0.14.0',
    }, {
        '@angular-devkit/build-angular': '^17.2.0',
        '@angular/compiler-cli': '^17.2.0',
        '@nx/angular': versions['@nx/angular'],
        '@nx/devkit': versions['@nx/devkit'],
        '@nx/eslint': versions['@nx/eslint'],
        typescript: '~5.3.0',
    });
    return (0, version_utils_1.getInstalledPackageVersion)(tree, '@angular/core', null, true);
};
const initWithNrwlNamespace = async (tree, installedNxVersion, skipFormat = true) => {
    const versions = (0, nx_dependencies_1.getNrwlDependencies)(installedNxVersion);
    try {
        (0, devkit_1.ensurePackage)('@nrwl/devkit', versions['@nrwl/devkit']);
        (0, devkit_1.ensurePackage)('@nrwl/angular', versions['@nrwl/angular']);
        (0, devkit_1.ensurePackage)('@nrwl/linter', versions['@nrwl/linter']);
    }
    catch {
        // @nx/angular cannot be required so this fails but this will still allow executing the nx angular init later on
    }
    (0, devkit_1.addDependenciesToPackageJson)(tree, {}, {
        '@nrwl/devkit': versions['@nrwl/devkit'],
        '@nrwl/angular': versions['@nrwl/angular'],
        '@nrwl/linter': versions['@nrwl/linter'],
    });
    await (await Promise.resolve().then(() => require(
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    '@nrwl/angular/generators'))).angularInitGenerator(tree, {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        skipInstall: true,
        skipFormat: skipFormat,
    });
    return (0, version_utils_1.getInstalledPackageVersion)(tree, '@angular/core', null, true);
};
//# sourceMappingURL=initialize-analog-workspace.js.map